@@ -1,10 +1,10 @@
 package Net::DNS::Resolver::Base;
 
 #
-# $Id: Base.pm 1475 2016-04-15 09:46:40Z willem $
+# $Id: Base.pm 1477 2016-04-17 11:55:34Z willem $
 #
 use vars qw($VERSION);
-$VERSION = (qw$LastChangedRevision: 1475 $)[1];
+$VERSION = (qw$LastChangedRevision: 1477 $)[1];
 
 
 use strict;
@@ -660,6 +660,7 @@ sub bgbusy {
 	}
 
 	return if $self->{igntc};
+	return unless $query;
 	return unless $handle->socktype() == SOCK_DGRAM;
 
 	my $ans = $self->_bgread($handle);
@@ -668,9 +669,7 @@ sub bgbusy {
 	return unless $ans->header->tc;
 
 	$self->_diag('packet truncated: retrying using TCP');
-	my $packet = new Net::DNS::Packet();
-	$packet->{question} = $ans->{question};
-	my $tcp = $self->_bgsend_tcp( $packet, $packet->data );
+	my $tcp = $self->_bgsend_tcp( $query, $query->data );
 	return defined( $_[1] = $tcp ) if $tcp;
 }
 
